function varargout = Toolbox_SHA_TEST_2(varargin)
%TOOLBOX_SHA_TEST_2 MATLAB code file for Toolbox_SHA_TEST_2.fig
%      TOOLBOX_SHA_TEST_2, by itself, creates a new TOOLBOX_SHA_TEST_2 or raises the existing
%      singleton*.
%
%      H = TOOLBOX_SHA_TEST_2 returns the handle to a new TOOLBOX_SHA_TEST_2 or the handle to
%      the existing singleton*.
%
%      TOOLBOX_SHA_TEST_2('Property','Value',...) creates a new TOOLBOX_SHA_TEST_2 using the
%      given property value pairs. Unrecognized properties are passed via
%      varargin to Toolbox_SHA_TEST_2_OpeningFcn.  This calling syntax produces a
%      warning when there is an existing singleton*.
%
%      TOOLBOX_SHA_TEST_2('CALLBACK') and TOOLBOX_SHA_TEST_2('CALLBACK',hObject,...) call the
%      local function named CALLBACK in TOOLBOX_SHA_TEST_2.M with the given input
%      arguments.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help Toolbox_SHA_TEST_2

% Last Modified by GUIDE v2.5 23-May-2019 14:48:12

% Begin initialization code - DO NOT EDIT

gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @Toolbox_SHA_TEST_2_OpeningFcn, ...
                   'gui_OutputFcn',  @Toolbox_SHA_TEST_2_OutputFcn, ...
                   'gui_LayoutFcn',  [], ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
   gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before Toolbox_SHA_TEST_2 is made visible.
function Toolbox_SHA_TEST_2_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   unrecognized PropertyName/PropertyValue pairs from the command line (see VARARGIN)

% Choose default command line output for Toolbox_SHA_TEST_2
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes Toolbox_SHA_TEST_2 wait for user response (see UIRESUME)
 uiwait(handles.figure1);
 set(hObject,'toolbar','figure');                      % Toolbar appear in the window
 set(hObject,'menubar','figure');                   % Menubar appear in the window


 
% --- Outputs from this function are returned to the command line.
function varargout = Toolbox_SHA_TEST_2_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure

varargout{1} = handles.output;

% The figure can be deleted now
delete(handles.figure1);

% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

handles.output = 1;

% Update handles structure
guidata(hObject, handles);

% Use UIRESUME instead of delete because the OutputFcn needs
% to get the updated handles structure.
uiresume(handles.figure1);

% --- Executes on button press in pushbutton2.
function pushbutton2_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

handles.output = 2;

% Update handles structure
guidata(hObject, handles);

% Use UIRESUME instead of delete because the OutputFcn needs
% to get the updated handles structure.
uiresume(handles.figure1);
% --- Executes on button press in pushbutton3.


function pushbutton3_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
handles.output = 3;

% Update handles structure
guidata(hObject, handles);

% Use UIRESUME instead of delete because the OutputFcn needs
% to get the updated handles structure.
uiresume(handles.figure1);


% --- Executes on button press in pushbutton4.
function pushbutton4_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
handles.output = 4;

% Update handles structure
guidata(hObject, handles);

% Use UIRESUME instead of delete because the OutputFcn needs
% to get the updated handles structure.
uiresume(handles.figure1);


% --- Executes when user attempts to close figure1.
function figure1_CloseRequestFcn(hObject, eventdata, handles)
% hObject    handle to figure1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

if isequal(get(hObject, 'waitstatus'), 'waiting')
    % The GUI is still in UIWAIT, us UIRESUME
    uiresume(hObject);
else
    % The GUI is no longer waiting, just close it
    delete(hObject);
end
